@@ -7,8 +7,6 @@ import warnings
 from enum import IntEnum
 from functools import wraps
 from pathlib import Path
-from pathlib import PosixPath
-from pathlib import PurePath
 from typing import Any
 from typing import Callable
 from typing import Dict
